﻿using Infragistics.Win.UltraWinSchedule;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace KB1218_UltraTimelineView_TimeSlotBackColor
{
    public partial class Form1 : Form
    {
        // 現在時刻を強調表示するためのAppearanceを作成する。
        private Infragistics.Win.Appearance _nowAppearance = new Infragistics.Win.Appearance { BackColor = Color.Red };

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            // オーナーのデータ バインディングに必要なサンプル データを取得
            DataSet ds = this.GetSampleData();

            // 未指定のオーナーを非表示にする
            this.ultraCalendarInfo1.Owners.UnassignedOwner.Visible = false;

            // ultraCalendarInfo を Owners データ テーブルにバインド
            // ultraTimelineView のビューに表示するオーナー数をバインドしたOwnersテーブルの行数とする
            this.ultraCalendarInfo1.DataBindingsForOwners.DataSource = ds.Tables["Owners"];
            this.ultraTimelineView1.MaximumOwnersInView = ds.Tables["Owners"].Rows.Count;

            // Owners データ バインディング プロパティを UltraCalendarInfo に設定
            this.ultraCalendarInfo1.DataBindingsForOwners.KeyMember = "OwnerKey";
            this.ultraCalendarInfo1.DataBindingsForOwners.NameMember = "Name";

            // 表示時間間隔の設定
            this.ultraTimelineView1.PrimaryInterval = new TimeInterval(1, TimeIntervalUnits.Minutes);
            this.ultraTimelineView1.AdditionalIntervals.Add(new DateInterval(1, DateIntervalUnits.Days));

            // 左端に表示する日時の設定
            //DateTime dtToday = DateTime.Today;
            DateTime dtNow = DateTime.Now;
            this.ultraTimelineView1.EnsureDateTimeVisible(new DateTime(dtNow.Year, dtNow.Month, dtNow.Day, dtNow.Hour, dtNow.Minute - 2, 0));

            // UltraCalendarInfoとUltraCalendarLookコントロールに指定
            this.ultraTimelineView1.CalendarInfo = this.ultraCalendarInfo1;



            // TimeRangeAppearancesプロパティを使って、特定の時間枠の色を変える。
            // https://jp.infragistics.com/help/winforms/infragistics.win.ultrawinschedule~infragistics.win.ultrawinschedule.ownertimeslotsettings~timerangeappearances

            // 各オーナーに関して
            for (int i = 0; i < ultraCalendarInfo1.Owners.Count; i++)
            {
                Owner owner = ultraCalendarInfo1.Owners[i];

                // 現在時刻を取得する。
                DateTime now = DateTime.Now;

                // オーナーのDateSettingsに新規のOwnerDateSettingsを追加する。
                OwnerDateSettings ownerDateSettings = owner.DateSettings.Add(new DateTime(now.Year, now.Month, now.Day));

                // 現在時刻をもとに、1分間のTimeRangeを作成する。
                TimeRange newTimeRange = new TimeRange(TimeSpan.FromHours(now.Hour) + TimeSpan.FromMinutes(now.Minute), TimeSpan.FromHours(now.Hour) + TimeSpan.FromMinutes(now.Minute + 1));

                // 現在時刻を強調表示するAppearanceを設定する。
                ownerDateSettings.TimeRangeAppearances.Add(newTimeRange, _nowAppearance);
            }
        }

        private DataSet GetSampleData()
        {
            DataSet ds = new DataSet();

            // Owners DataTable を作成
            DataTable dtOwners = ds.Tables.Add("Owners");
            dtOwners.Columns.Add("OwnerID", typeof(int));
            dtOwners.Columns.Add("Name", typeof(String));
            dtOwners.Columns.Add("OwnerKey", typeof(String));

            // Owners サンプル データを追加
            dtOwners.Rows.Add(new object[] { "1", "Owner 1", "Owner1" });
            dtOwners.Rows.Add(new object[] { "2", "Owner 2", "Owner2" });
            dtOwners.Rows.Add(new object[] { "3", "Owner 3", "Owner3" });

            return ds;
        }
    }
}
